@@ -1,6 +1,7 @@
 /* typecast_binary.c - binary typecasting functions to python types
  *
- * Copyright (C) 2001-2010 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2001-2019 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2020 The Psycopg Team
  *
  * This file is part of psycopg.
  *
@@ -53,7 +54,7 @@ chunk_repr(chunkObject *self)
       );
 }
 
-#if PY_MAJOR_VERSION < 3
+#if PY_2
 
 static Py_ssize_t
 chunk_getreadbuffer(chunkObject *self, Py_ssize_t segment, void **ptr)
@@ -132,9 +133,9 @@ PyTypeObject chunkType = {
 };
 
 
-static char *psycopg_parse_hex(
+static char *parse_hex(
         const char *bufin, Py_ssize_t sizein, Py_ssize_t *sizeout);
-static char *psycopg_parse_escape(
+static char *parse_escape(
         const char *bufin, Py_ssize_t sizein, Py_ssize_t *sizeout);
 
 /* The function is not static and not hidden as we use ctypes to test it. */
@@ -154,7 +155,7 @@ typecast_BINARY_cast(const char *s, Py_ssize_t l, PyObject *curs)
          * So the only robust option is to parse it ourselves - luckily it's
          * an easy format.
          */
-        if (NULL == (buffer = psycopg_parse_hex(s, l, &len))) {
+        if (NULL == (buffer = parse_hex(s, l, &len))) {
             goto exit;
         }
     }
@@ -169,7 +170,7 @@ typecast_BINARY_cast(const char *s, Py_ssize_t l, PyObject *curs)
          * So we'll just have our better integrated parser, let's finish this
          * story.
          */
-        if (NULL == (buffer = psycopg_parse_escape(s, l, &len))) {
+        if (NULL == (buffer = parse_escape(s, l, &len))) {
             goto exit;
         }
     }
@@ -182,7 +183,7 @@ typecast_BINARY_cast(const char *s, Py_ssize_t l, PyObject *curs)
     buffer = NULL;
     chunk->len = (Py_ssize_t)len;
 
-#if PY_MAJOR_VERSION < 3
+#if PY_2
     if ((res = PyBuffer_FromObject((PyObject *)chunk, 0, chunk->len)) == NULL)
         goto exit;
 #else
@@ -212,14 +213,14 @@ static const char hex_lut[128] = {
 /* Parse a bytea output buffer encoded in 'hex' format.
  *
  * the format is described in
- * http://www.postgresql.org/docs/current/static/datatype-binary.html
+ * https://www.postgresql.org/docs/current/static/datatype-binary.html
  *
  * Parse the buffer in 'bufin', whose length is 'sizein'.
  * Return a new buffer allocated by PyMem_Malloc and set 'sizeout' to its size.
  * In case of error set an exception and return NULL.
  */
 static char *
-psycopg_parse_hex(const char *bufin, Py_ssize_t sizein, Py_ssize_t *sizeout)
+parse_hex(const char *bufin, Py_ssize_t sizein, Py_ssize_t *sizeout)
 {
     char *ret = NULL;
     const char *bufend = bufin + sizein;
@@ -262,14 +263,14 @@ exit:
 /* Parse a bytea output buffer encoded in 'escape' format.
  *
  * the format is described in
- * http://www.postgresql.org/docs/current/static/datatype-binary.html
+ * https://www.postgresql.org/docs/current/static/datatype-binary.html
  *
  * Parse the buffer in 'bufin', whose length is 'sizein'.
  * Return a new buffer allocated by PyMem_Malloc and set 'sizeout' to its size.
  * In case of error set an exception and return NULL.
  */
 static char *
-psycopg_parse_escape(const char *bufin, Py_ssize_t sizein, Py_ssize_t *sizeout)
+parse_escape(const char *bufin, Py_ssize_t sizein, Py_ssize_t *sizeout)
 {
     char *ret = NULL;
     const char *bufend = bufin + sizein;
@@ -312,4 +313,3 @@ psycopg_parse_escape(const char *bufin, Py_ssize_t sizein, Py_ssize_t *sizeout)
 exit:
     return ret;
 }
-
