@@ -1,6 +1,7 @@
 /* win32_support.h - definitions for win32_support.c
  *
  * Copyright (C) 2003-2019 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2020 The Psycopg Team
  *
  * This file is part of psycopg.
  *
@@ -43,6 +44,13 @@ extern HIDDEN void timeradd(struct timeval *a, struct timeval *b, struct timeval
 #endif
 
 extern HIDDEN void timersub(struct timeval *a, struct timeval *b, struct timeval *c);
+
+#ifndef timercmp
+#define timercmp(a, b, cmp)          \
+  (((a)->tv_sec == (b)->tv_sec) ?    \
+   ((a)->tv_usec cmp (b)->tv_usec) : \
+   ((a)->tv_sec  cmp (b)->tv_sec))
+#endif
 #endif
 
 #endif /* !defined(PSYCOPG_WIN32_SUPPORT_H) */
