@@ -33,7 +33,8 @@ import psycopg2
 import psycopg2.errors
 from psycopg2 import extensions as ext
 
-from .testutils import ConnectingTestCase, StringIO, skip_before_postgres, slow
+from .testutils import (ConnectingTestCase, StringIO, skip_before_postgres,
+    skip_if_crdb, crdb_version, slow)
 
 
 class PollableStub(object):
@@ -62,6 +63,10 @@ class AsyncTests(ConnectingTestCase):
         self.wait(self.conn)
 
         curs = self.conn.cursor()
+        if crdb_version(self.sync_conn) is not None:
+            curs.execute("set experimental_enable_temp_tables = 'on'")
+            self.wait(curs)
+
         curs.execute('''
             CREATE TEMPORARY TABLE table1 (
               id int PRIMARY KEY
@@ -109,7 +114,6 @@ class AsyncTests(ConnectingTestCase):
 
         self.wait(cur)
         self.assertFalse(self.conn.isexecuting())
-        self.assertEquals(cur.fetchall()[0][0], '')
 
     @slow
     def test_async_after_async(self):
@@ -324,6 +328,7 @@ class AsyncTests(ConnectingTestCase):
         conn.close()
 
     @slow
+    @skip_if_crdb("flush on write flakey")
     def test_flush_on_write(self):
         # a very large query requires a flush loop to be sent to the backend
         curs = self.conn.cursor()
@@ -350,6 +355,7 @@ class AsyncTests(ConnectingTestCase):
         self.assertEquals(cur.fetchone()[0], 1)
 
     @slow
+    @skip_if_crdb("notify")
     def test_notify(self):
         cur = self.conn.cursor()
         sync_cur = self.sync_conn.cursor()
@@ -394,11 +400,12 @@ class AsyncTests(ConnectingTestCase):
         self.assertRaises(psycopg2.IntegrityError, self.wait, cur)
         cur.execute("insert into table1 values (%s); "
                     "insert into table1 values (%s)", (2, 2))
-        # this should fail as well
+        # this should fail as well (Postgres behaviour)
         self.assertRaises(psycopg2.IntegrityError, self.wait, cur)
         # but this should work
-        cur.execute("insert into table1 values (%s)", (2, ))
-        self.wait(cur)
+        if crdb_version(self.sync_conn) is None:
+            cur.execute("insert into table1 values (%s)", (2, ))
+            self.wait(cur)
         # and the cursor should be usable afterwards
         cur.execute("insert into table1 values (%s)", (3, ))
         self.wait(cur)
@@ -426,6 +433,7 @@ class AsyncTests(ConnectingTestCase):
         self.wait(cur2)
         self.assertEquals(cur2.fetchone()[0], 1)
 
+    @skip_if_crdb("notice")
     def test_notices(self):
         del self.conn.notices[:]
         cur = self.conn.cursor()
@@ -450,6 +458,7 @@ class AsyncTests(ConnectingTestCase):
         self.wait(self.conn)
         self.assertEqual(cur.fetchone(), (42,))
 
+    @skip_if_crdb("copy")
     def test_async_connection_error_message(self):
         try:
             cnn = psycopg2.connect('dbname=thisdatabasedoesntexist', async_=True)
@@ -467,6 +476,7 @@ class AsyncTests(ConnectingTestCase):
         self.assertRaises(psycopg2.ProgrammingError, self.wait, self.conn)
 
     @slow
+    @skip_if_crdb("notice")
     @skip_before_postgres(9, 0)
     def test_non_block_after_notification(self):
         from select import select
@@ -500,6 +510,7 @@ class AsyncTests(ConnectingTestCase):
     def test_poll_noop(self):
         self.conn.poll()
 
+    @skip_if_crdb("notify")
     @skip_before_postgres(9, 0)
     def test_poll_conn_for_notification(self):
         with self.conn.cursor() as cur:
@@ -522,6 +533,11 @@ class AsyncTests(ConnectingTestCase):
         else:
             self.fail("No notification received")
 
+    def test_close(self):
+        self.conn.close()
+        self.assertTrue(self.conn.closed)
+        self.assertTrue(self.conn.async_)
+
 
 def test_suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
